@@ -42,6 +42,8 @@ FIXTURE_PATH = Path(__file__).parent.joinpath("fixtures", "container.md")
 @pytest.mark.parametrize("line,title,input,expected", read_fixture_file(FIXTURE_PATH))
 def test_all(line, title, input, expected):
     md = MarkdownIt("commonmark").use(container_plugin, "name")
+    if "DISABLE-CODEBLOCKS" in title:
+        md.disable("code")
     md.options["xhtmlOut"] = False
     text = md.render(input)
     print(text)
